@@ -31,6 +31,7 @@ __all__ = (
     "KafkaSettingsTypeDef",
     "KinesisSettingsTypeDef",
     "MongoDbSettingsTypeDef",
+    "NeptuneSettingsTypeDef",
     "RedshiftSettingsTypeDef",
     "S3SettingsTypeDef",
     "EndpointTypeDef",
@@ -190,6 +191,26 @@ MongoDbSettingsTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredNeptuneSettingsTypeDef = TypedDict(
+    "_RequiredNeptuneSettingsTypeDef", {"S3BucketName": str, "S3BucketFolder": str}
+)
+_OptionalNeptuneSettingsTypeDef = TypedDict(
+    "_OptionalNeptuneSettingsTypeDef",
+    {
+        "ServiceAccessRoleArn": str,
+        "ErrorRetryDuration": int,
+        "MaxFileSize": int,
+        "MaxRetryCount": int,
+        "IamAuthEnabled": bool,
+    },
+    total=False,
+)
+
+
+class NeptuneSettingsTypeDef(_RequiredNeptuneSettingsTypeDef, _OptionalNeptuneSettingsTypeDef):
+    pass
+
+
 RedshiftSettingsTypeDef = TypedDict(
     "RedshiftSettingsTypeDef",
     {
@@ -277,6 +298,7 @@ EndpointTypeDef = TypedDict(
         "KinesisSettings": KinesisSettingsTypeDef,
         "KafkaSettings": KafkaSettingsTypeDef,
         "ElasticsearchSettings": ElasticsearchSettingsTypeDef,
+        "NeptuneSettings": NeptuneSettingsTypeDef,
         "RedshiftSettings": RedshiftSettingsTypeDef,
     },
     total=False,
@@ -427,6 +449,7 @@ ReplicationTaskTypeDef = TypedDict(
         "RecoveryCheckpoint": str,
         "ReplicationTaskArn": str,
         "ReplicationTaskStats": ReplicationTaskStatsTypeDef,
+        "TaskData": str,
     },
     total=False,
 )
@@ -521,6 +544,7 @@ SupportedEndpointTypeTypeDef = TypedDict(
         "EngineName": str,
         "SupportsCDC": bool,
         "EndpointType": Literal["source", "target"],
+        "ReplicationInstanceEngineMinimumVersion": str,
         "EngineDisplayName": str,
     },
     total=False,
